/*
  xtbar.h
  Definitions for XtScrollBar and XtProgressBar

  Copyright (c) 1996-98 Adrian Teohar, Dragos Acostachioaie
  Documentation Copyright (c) 1998 Dragos Acostachioaie

  This file is part of Xterminal library.

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the license, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public
  License along with this program; if not, write to the Free
  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#ifndef _XTBAR_H
#define _XTBAR_H

#include <xobject.h>

/**
    @memo Scroll bar
    @author Adrian Teohar
    @version 0.1
*/
class XtScrollBar : public XObject {
 public:

  /** Constructs a new XtScrollBar
      @param __r bar bounds
      @param __TotalNo total items number
      @param __Horizontal true if it's horizontally positioned
  */
  XtScrollBar(XRect __r, long __TotalNo, unsigned __Horizontal);

  /// Draws the object
  virtual void Draw();

  /// Returns the total items number
  long GetTotalNo();

  /// Process mouse events
  virtual int ProcessMouseEvent(XMouseEvent *__Event);

  /// Sets the total items number
  void SetTotalNo(long __ItemNo);

  /// Sets the current count value
  void SetValue(long __ItemNo);

 protected:
  bool Horizontal;
  long CurrentNo, MaxNo;
};  

// Progress Bar directions
#define PB_LEFT_TO_RIGHT	0x01
#define PB_RIGHT_TO_LEFT	0x02
#define PB_BOTTOM_TO_TOP	0x03
#define PB_TOP_TO_BOTTOM	0x04

/**
    @memo Progress bar
    @author Adrian Teohar
    @version 0.1
*/
class XtProgressBar : public XObject {
 public:

  /** Constructs a new XtProgressBar
      @param __r bar bounds
      @param __TotalNo total items number
      @param __Direction direction the progress is going, which can be:
         <p>PB_LEFT_TO_RIGHT left to the right
	 <p>PB_RIGHT_TO_LEFT right to the left
	 <p>PB_BOTTOM_TO_TOP bottom to the top
	 <p>PB_TOP_TO_BOTTOM top to the bottom
  */
  XtProgressBar(XRect __r, long __TotalNo, unsigned __Direction);

  /// Draws the object
  virtual void Draw();

  /// Returns the progress percentual value
  float GetPercent();

  /// Returns the total items number
  long GetTotalNo();

  /// Returns the current count value
  long GetValue();

  /// Sets the total items number
  void SetTotalNo(long __ItemNo);

  /// Sets the current count value
  void SetValue(long __ItemNo);

 protected:
  long CurrentNo, MaxNo;
  float Percent;
  unsigned Poz, Len;
  unsigned Direction;
};

// Bar-related events
#define SCROLLBAR_ITEMUP	0x0010
#define SCROLLBAR_ITEMDOWN	0x0011

// Bars palette entries
#define P_BAR_LEN	4

#define P_BAR_MARKERS	0x01
#define P_BAR_BAR	0x03

#endif
