/*
  xtdialog.h
  Definitions for the XtDialog and XtDialogBox

  Copyright (c) 1996-98 Dragos Acostachioaie

  This file is part of Xterminal library.

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the license, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public
  License along with this program; if not, write to the Free
  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#ifndef _XTDIALOG_H
#define _XTDIALOG_H

#include <xbclass.h>
#include <xobject.h>
#include <xtpassive.h>

/**
    @memo Dialog containing multiple active objects
    @author Dragos Acostachioaie
    @version 0.1
*/
class XtDialog : public XObject {
// this is a quite general class
 public:

  /// Constructs a new XtDialog with the specified bounds
  XtDialog(XRect __r);

  /** Handles the object passed as argument, by calling ProcessEvent() method
      of all the registered clients
  */
  virtual void HandleEvent(XEvent *__Ev);

  /// Process messages
  virtual int ProcessMessage(XMessage *__Event);
};

/**
    @memo Dialog window containing multiple active objects
    @author Dragos Acostachioaie
    @version 0.1
*/
class XtDialogBox : public XtDialog {
 public:

  /// Constructs a new dialog window with the specified bounds and title
  XtDialogBox(XRect __r, char *__Title);

  /// Destructs the object's instance
  virtual ~XtDialogBox();

  /// Draws the dialog window and all the registered clients
  virtual void Draw();

  /// Move the dialog's origin to the specified point
  virtual void MoveTo(XPoint __p);

  /** "Runs" the dialog: waits for events until the dialog is closed (e.g. the
      CM_CLOSE command is received)
  */
  virtual void Run();

  /// Process keyboard events
  virtual int ProcessKeyboardEvent(XKeyboardEvent *__Event);

  /// Process mouse events
  virtual int ProcessMouseEvent(XMouseEvent *__Event);

  /// Sets the object's state
  virtual void SetState(int __Mask, int __BoolValue);

 protected:
  XtWindow *Wnd;
  XPoint Adjust;
};

extern unsigned DIALOGBOX_MOVE_KEY, DIALOGBOX_CLOSE_KEY;

#endif
