/*
  xtfield.h
  Definition for XtInputStringField and XtInputNumericField

  Copyright (c) 1996-98 Dragos Acostachioaie

  This file is part of Xterminal library.

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the license, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public
  License along with this program; if not, write to the Free
  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#ifndef _XTFIELD_H
#define _XTFIELD_H

#include <xobject.h>
#include <xtscreen.h>

/**
    @memo Field to read strings
    @author Dragos Acostachioaie
    @version 0.1
*/
class XtInputStringField : public XObject {
 public:

  /** Constructs a new XtInputStringField.
      @param __r field bounds
      @param __DefaultString default string
      @param __MaxLen maximum string length
      @param __Crypted true if the output should be hidden
  */
  XtInputStringField(XRect __r, char *__DefaultString, unsigned __MaxLen, unsigned __Crypted);

  /// Destructs the object instance
  virtual ~XtInputStringField();

  /// Draws the object
  virtual void Draw();

  /// Process keyboard events
  virtual int ProcessKeyboardEvent(XKeyboardEvent *__Event);

  /// Process messages
  virtual int ProcessMessage(XMessage *__Event);

  /// Process mouse events
  virtual int ProcessMouseEvent(XMouseEvent *__Event);

  /// Sets the object's state
  virtual void SetState(int __Mask, int __BoolValue);

 protected:
  char *DefaultString, *CurrString;
  unsigned FieldLength, StringLength, MaxLen, CP, curX;
  char bchar;
  unsigned Encrypt, InsertMode, InputText;
};

#define ALLOW_NEGATIVE_VALUES	0x0001

/**
    Field to read numeric values
*/
class XtInputNumericField : public XtInputStringField {
 public:

  /** Constructs a new XtInputNumericField.
      @param __r field bounds
      @param __DefaultNumber default number
      @param __IntegerDigits maximum integer digits allowed
      @param __DecimalDigits maximum decimal digits allowed
      @param __Flags options, which can be:
         <p>ALLOW_NEGATIVE_VALUES - to allow entering negative values
  */
  XtInputNumericField(XRect __r, double __DefaultNumber, unsigned short __IntegerDigits, unsigned short __DecimalDigits, unsigned long __Flags);

  virtual int ProcessKeyboardEvent(XKeyboardEvent *__Event);
  virtual int ProcessMessage(XMessage *__Event);

 private:
  unsigned short IntegerDigits, DecimalDigits;
  unsigned long Flags;
};

// Fields palette entries
#define P_FIELD_LEN	4

#define P_FIELD_TEXT	0x01
#define P_FIELD_DEFAULT	0x03

#endif
