/*
  xtpassive.h
  Definitions for passive objects, XtWindow and XtStaticText

  Copyright (c) 1996-98 Dragos Acostachioaie

  This file is part of Xterminal library.

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the license, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public
  License along with this program; if not, write to the Free
  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#ifndef _XTPASSIVE_H
#define _XTPASSIVE_H

#include <xtscreen.h>
#include <xobject.h>

/**
    @memo Window class
    @author Dragos Acostachioaie
    @version 0.1
*/
class XtWindow : public XObject {
 public:

  /// Constructs a new XtWindow with the specified bounds and title
  XtWindow(XRect __r, char *__Title);

  /// Destructs the XtWindow instance
  virtual ~XtWindow();

  /// Close the window
  virtual void Close();

  /// Draws the window
  virtual void Draw();

  /// Move the upper-left window corner to the specified coordinate
  virtual void MoveTo(XPoint __p);

  /** Process message events. __Event->Message can be:
      <p>WM_CLOSE - request to close the window
      <p>WM_OPEN - request to open the window (e.g. to draw it)
      <p>WM_MOVE - request to move the window
  */
  virtual int ProcessMessage(XMessage *__Event);

  /// Set the frame style
  virtual void SetFrame(char *__Frame);

  /// Sets the window state
  virtual void SetState(int __Mask, int __BoolValue);

 protected:

  /// Buffer to save the old screen area
  chtype *Buffer;

  /// Window title
  char Title[40];

  /// Window frame
  char Frame[10];

  /// Updates window margins
  void FrameUpdate();
};

//extern chtype WND_CLOSE_MARKER, WND_ZOOM_MARKER;

// Window Messages
#define WM_CLOSE     0x0001
#define WM_OPEN      0x0002
#define WM_MOVE      0x0004

/* XtWindow State Masks */
#define WM_HAVE_SHADOW	0x0800
#define WM_CAN_CLOSE	0x1000
#define WM_CAN_MOVE	0x2000
#define WM_CAN_ZOOM	0x4000
#define WM_CAN_RESIZE	0x8000

// Window palette entries
#define P_WINDOW_LEN			14

#define P_WINDOW_SURFACE		0x01
#define P_WINDOW_FRAME			0x03
#define P_WINDOW_TITLE			0x05
#define P_WINDOW_UNFOCUSED_FRAME	0x07
#define P_WINDOW_UNFOCUSED_TITLE	0x09
#define P_WINDOW_SHADOW			0x0B
#define P_WINDOW_MARKERS		0x0D

// Align Styles
#define AS_NO_ALIGN	0x00
#define AS_LEFT		0x01
#define AS_CENTER	0x02
#define AS_RIGHT	0x03
#define AS_TOP		0x04
#define AS_BOTTOM	0x05
#define AS_MIDDLE	0x06

/**
    @memo Static text class
    @author Dragos Acostachioaie
    @version 0.1
*/
class XtStaticText : public XObject {
 public:

  /// Constructs a new XtStaticText with the specified bounds, alignment and text
  XtStaticText(XRect __r, unsigned __Alignment, char *__Text);

  /// Draws the text
  virtual void Draw();

  /// Sets the text
  virtual void SetValue(char *__Text);

 protected:

  /// Text
  char Text[80];

  /** Align style. Can be:
      <p>AS_NO_ALIGN - no align is made
      <p>AS_LEFT - align to the left
      <p>AS_CENTER - center the text horizontally
      <p>AS_RIGHT - align to the right
      <p>AS_TOP - align to the top
      <p>AS_BOTTOM - align to the bottom
      <p>AS_MIDDLE - center the text vertically
  */
  unsigned Alignment;
};

// StaticText palette entries
#define P_STATICTEXT_LEN	2

#define P_STATICTEXT_TEXT	0x01

#define SHORTCUT_LETTER '~'

#endif
